@@ -35,11 +35,11 @@ SNA::Network - A toolkit for Social Network Analysis
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 
 =head1 SYNOPSIS
@@ -103,7 +103,7 @@ or load a network from a file.
 
 sub new {
 	my ($package) = @_;
-	return bless { nodes => [], edges => [] }, $package;
+	return bless { nodes => [], edges => [], communities_ref => [] }, $package;
 }
 
 
@@ -312,7 +312,7 @@ If no such algorithm had been executed, it returns C<undef>.
 =head2 communities
 
 Return a list of L<SNA::Network::Community> objects, which were identified by a previously executed community identification algorithm, usually the L<SNA::Network::Algorithm::Louvain> algorithm.
-If no such algorithm was executed, returns C<undef>.
+If no such algorithm was executed, returns an empty list.
 
 =cut
 
